==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints.md <==
# AmazonSimpleStorageServiceGeneralAccessPoints


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')
```



| Illustration | AmazonSimpleStorageServiceGeneralAccessPoints | AmazonSimpleStorageServiceGeneralAccessPointsCard | AmazonSimpleStorageServiceGeneralAccessPointsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints.png) | ![illustration for AmazonSimpleStorageServiceGeneralAccessPoints](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints.Local.png) | ![illustration for AmazonSimpleStorageServiceGeneralAccessPointsCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPointsCard.Local.png) | ![illustration for AmazonSimpleStorageServiceGeneralAccessPointsGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPointsGroup.Local.png) |




## AmazonSimpleStorageServiceGeneralAccessPoints

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPoints
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPoints('AmazonSimpleStorageServiceGeneralAccessPoints', 'Amazon Simple Storage Service General Access Points', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPoints
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPoints('AmazonSimpleStorageServiceGeneralAccessPoints', 'Amazon Simple Storage Service General Access Points', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceGeneralAccessPointsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsCard('AmazonSimpleStorageServiceGeneralAccessPointsCard', 'Amazon Simple Storage Service General Access Points Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsCard('AmazonSimpleStorageServiceGeneralAccessPointsCard', 'Amazon Simple Storage Service General Access Points Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceGeneralAccessPointsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsGroup('AmazonSimpleStorageServiceGeneralAccessPointsGroup', 'Amazon Simple Storage Service General Access Points Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsGroup('AmazonSimpleStorageServiceGeneralAccessPointsGroup', 'Amazon Simple Storage Service General Access Points Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints.md <==
# AmazonSimpleStorageServiceGeneralAccessPoints


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')
```



| Illustration | AmazonSimpleStorageServiceGeneralAccessPoints | AmazonSimpleStorageServiceGeneralAccessPointsCard | AmazonSimpleStorageServiceGeneralAccessPointsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints.png) | ![illustration for AmazonSimpleStorageServiceGeneralAccessPoints](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints.Local.png) | ![illustration for AmazonSimpleStorageServiceGeneralAccessPointsCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPointsCard.Local.png) | ![illustration for AmazonSimpleStorageServiceGeneralAccessPointsGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPointsGroup.Local.png) |




## AmazonSimpleStorageServiceGeneralAccessPoints

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPoints
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPoints('AmazonSimpleStorageServiceGeneralAccessPoints', 'Amazon Simple Storage Service General Access Points', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPoints
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPoints('AmazonSimpleStorageServiceGeneralAccessPoints', 'Amazon Simple Storage Service General Access Points', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceGeneralAccessPointsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsCard('AmazonSimpleStorageServiceGeneralAccessPointsCard', 'Amazon Simple Storage Service General Access Points Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsCard('AmazonSimpleStorageServiceGeneralAccessPointsCard', 'Amazon Simple Storage Service General Access Points Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceGeneralAccessPointsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsGroup('AmazonSimpleStorageServiceGeneralAccessPointsGroup', 'Amazon Simple Storage Service General Access Points Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGeneralAccessPointsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGeneralAccessPoints')

' renders the element
AmazonSimpleStorageServiceGeneralAccessPointsGroup('AmazonSimpleStorageServiceGeneralAccessPointsGroup', 'Amazon Simple Storage Service General Access Points Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
